using System;

namespace MyBalanceOfPower
{
	/// <summary>
	/// The building stats customizer class.
	/// </summary>
	public static class Rebuilder
	{
		/// <summary>
		/// Modifies stats for a building.
		/// </summary>
		/// <param name="name">The name of the building.</param>
		/// <param name="localizedName">The (possibly) localized name of the building.</param>
		/// <param name="plant">The AI object for the building.</param>
		public static void Modify(string name, string localizedName, PowerPlantAI plant)
		{
			#region Nuclear Power Plant
			if (string.Equals(name, "Nuclear Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Nuclear Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 1000000;
				plant.m_maintenanceCost = 28000;
				plant.m_electricityProduction = 32000;
				plant.m_pollutionRadius = 0;
				plant.m_sewageAccumulation = 20;
				plant.m_resourceType = TransferManager.TransferReason.Ore;
				plant.m_resourceConsumption = 8;
				plant.m_resourceCapacity = 9152;
				plant.m_workPlaceCount1 = 20;
				return;
			}
			#endregion Nuclear Power Plant

			#region Wind Turbine
			if (string.Equals(name, "Wind Turbine", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Wind Turbine", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 12000;
				plant.m_maintenanceCost = 700;
				plant.m_electricityProduction = 625;
				plant.m_noiseAccumulation = 100;
				plant.m_noiseRadius = 200;
				plant.m_resourceConsumption = 0;
				return;
			}
			#endregion Wind Turbine

			#region Solar Power Plant
			if (string.Equals(name, "Solar Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Solar Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 96000;
				plant.m_maintenanceCost = 2638;
				plant.m_electricityProduction = 2812;
				plant.m_noiseAccumulation = 2;
				plant.m_noiseRadius = 50;
				plant.m_resourceConsumption = 0;
				plant.m_workPlaceCount1 = 2;
				plant.m_workPlaceCount2 = 2;
				plant.m_workPlaceCount3 = 1;
				return;
			}
			#endregion Solar Power Plant

			#region Hydro Power Plant
			if (string.Equals(name, "Hydro Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Hydro Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_maintenanceCost = 25000;
				return;
			}
			#endregion Hydro Power Plant

			#region Advanced Wind Turbine
			if (string.Equals(name, "Advanced Wind Turbine", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Advanced Wind Turbine", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 40000;
				plant.m_maintenanceCost = 1400;
				plant.m_electricityProduction = 1500;
				plant.m_noiseAccumulation = 100;
				plant.m_noiseRadius = 200;
				plant.m_resourceConsumption = 0;
				return;
			}
			#endregion Advanced Wind Turbine

			#region Coal Power Plant
			if (string.Equals(name, "Coal Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Coal Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 18000;
				plant.m_maintenanceCost = 3000;
				plant.m_electricityProduction = 2750;
				plant.m_pollutionAccumulation = 100;
				plant.m_pollutionRadius = 500;
				plant.m_noiseAccumulation = 100;
				plant.m_noiseRadius = 75;
				plant.m_resourceConsumption = 15;
				plant.m_resourceCapacity = 9960;
				plant.m_fireHazard = 2;
				plant.m_fireTolerance = 50;
				plant.m_workPlaceCount0 = 40;
				return;
			}
			#endregion Coal Power Plant

			#region Oil Power Plant
			if (string.Equals(name, "Oil Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Oil Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 42000;
				plant.m_maintenanceCost = 7200;
				plant.m_electricityProduction = 6000;
				plant.m_pollutionAccumulation = 75;
				plant.m_pollutionRadius = 400;
				plant.m_noiseRadius = 75;
				plant.m_resourceConsumption = 20;
				plant.m_resourceCapacity = 10080;
				plant.m_fireHazard = 2;
				plant.m_fireTolerance = 50;
				plant.m_workPlaceCount0 = 20;
				plant.m_workPlaceCount1 = 30;
				plant.m_workPlaceCount2 = 30;
				return;
			}
			#endregion Oil Power Plant

			#region Fusion Power Plant
			if (string.Equals(name, "Fusion Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Fusion Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 25000000;
				plant.m_maintenanceCost = 100000;
				plant.m_pollutionRadius = 0;
				plant.m_noiseAccumulation = 50;
				plant.m_noiseRadius = 100;
				plant.m_waterConsumption = 50;
				plant.m_sewageAccumulation = 50;
				return;
			}
			#endregion Fusion Power Plant

			#region Wood-burning Power Plant
			if (string.Equals(name, "Wood-burning Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Wood-burning Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 7800;
				plant.m_maintenanceCost = 1562;
				plant.m_electricityConsumption = 0;
				plant.m_electricityProduction = 1500;
				plant.m_pollutionAccumulation = 100;
				plant.m_pollutionRadius = 500;
				plant.m_noiseAccumulation = 125;
				plant.m_noiseRadius = 50;
				plant.m_waterConsumption = 0;
				plant.m_sewageAccumulation = 0;
				plant.m_garbageAccumulation = 5;
				plant.m_resourceType = TransferManager.TransferReason.Lumber;
				plant.m_resourceConsumption = 15;
				plant.m_resourceCapacity = 9960;
				plant.m_fireHazard = 2;
				plant.m_fireTolerance = 50;
				plant.m_workPlaceCount0 = 50;
				plant.m_workPlaceCount1 = 0;
				plant.m_workPlaceCount2 = 0;
				plant.m_workPlaceCount3 = 0;
				return;
			}
			#endregion Wood-burning Power Plant

			#region Biodiesel Power Plant
			if (string.Equals(name, "Biodiesel Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Biodiesel Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 60000;
				plant.m_maintenanceCost = 7400;
				plant.m_electricityConsumption = 0;
				plant.m_electricityProduction = 6000;
				plant.m_pollutionAccumulation = 40;
				plant.m_pollutionRadius = 400;
				plant.m_noiseAccumulation = 30;
				plant.m_noiseRadius = 50;
				plant.m_waterConsumption = 40;
				plant.m_sewageAccumulation = 40;
				plant.m_garbageAccumulation = 10;
				plant.m_resourceType = TransferManager.TransferReason.Grain;
				plant.m_resourceConsumption = 20;
				plant.m_resourceCapacity = 10080;
				plant.m_fireHazard = 1;
				plant.m_fireTolerance = 20;
				plant.m_workPlaceCount0 = 5;
				plant.m_workPlaceCount1 = 20;
				plant.m_workPlaceCount2 = 30;
				plant.m_workPlaceCount3 = 10;
				return;
			}
			#endregion Biodiesel Power Plant

			#region Micronuclear Power Plant
			if (string.Equals(name, "Micronuclear Power Plant", StringComparison.InvariantCultureIgnoreCase) ||
				string.Equals(localizedName, "Micronuclear Power Plant", StringComparison.InvariantCultureIgnoreCase))
			{
				plant.m_constructionCost = 200000;
				plant.m_maintenanceCost = 11000;
				plant.m_electricityConsumption = 0;
				plant.m_electricityProduction = 10000;
				plant.m_pollutionAccumulation = 0;
				plant.m_pollutionRadius = 0;
				plant.m_noiseAccumulation = 20;
				plant.m_noiseRadius = 50;
				plant.m_waterConsumption = 60;
				plant.m_sewageAccumulation = 10;
				plant.m_garbageAccumulation = 5;
				plant.m_resourceType = TransferManager.TransferReason.Ore;
				plant.m_resourceConsumption = 4;
				plant.m_resourceCapacity = 5856;
				plant.m_fireHazard = 1;
				plant.m_fireTolerance = 20;
				plant.m_workPlaceCount0 = 0;
				plant.m_workPlaceCount1 = 10;
				plant.m_workPlaceCount2 = 25;
				plant.m_workPlaceCount3 = 15;
				return;
			}
			#endregion Micronuclear Power Plant
		}

		/// <summary>
		/// Modifies stats for a dam.
		/// </summary>
		/// <param name="name">The name of the dam.</param>
		/// <param name="localizedName">The (possibly) localized name of the dam.</param>
		/// <param name="plant">The AI object for the dam.</param>
		public static void Modify(string name, string localizedName, DamAI dam)
		{
			#region Dam
			dam.m_constructionCost = 320000;
			#endregion Dam
		}
	}
}