﻿using System;
using System.IO;
using System.Windows.Forms;
using PowerGenerator.Properties;

namespace PowerGenerator
{
	public partial class MainWindow : Form
	{
		public MainWindow()
		{
			InitializeComponent();
		}

		private void excelFilePathBrowseButton_Click(object sender, EventArgs e)
		{
			openExcelFileDialog.FileName = excelFilePathTextBox.Text;
			if (openExcelFileDialog.ShowDialog(this) == DialogResult.OK)
			{
				excelFilePathTextBox.Text = openExcelFileDialog.FileName;
			}
		}

		private void generateButton_Click(object sender, EventArgs e)
		{
			try
			{
				saveAddonFileDialog.FileName = "MyModFiles.cs";
				saveAddonFileDialog.InitialDirectory = Settings.Default.OutputPath;
				if (saveAddonFileDialog.ShowDialog(this) != DialogResult.OK)
					return;

				Settings.Default.OutputPath = Path.GetDirectoryName(saveAddonFileDialog.FileName);

				Worker.Generate(
					excelFilePathTextBox.Text,
					excelSheetNameTextBox.Text,
					includeDifferencesOnlyCheckBox.Checked,
					Settings.Default.OutputPath,
					addonNameTextBox.Text,
					addonDescriptionTextBox.Text,
					addonNamespaceTextBox.Text);

				MessageBox.Show(this, "Addon generated", "Success", MessageBoxButtons.OK, MessageBoxIcon.Information);
			}
			catch (Exception ex)
			{
				MessageBox.Show(this, ex.Message, "Failure", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void addonNamespace_KeyPress(object sender, KeyPressEventArgs e)
		{
			if (!char.IsControl(e.KeyChar) && !char.IsLetter(e.KeyChar))
			{
				e.Handled = true;
			}
		}

		private void MainWindow_FormClosed(object sender, FormClosedEventArgs e)
		{
			Settings.Default.ExcelFile = excelFilePathTextBox.Text;
			Settings.Default.ExcelSheetName = excelSheetNameTextBox.Text;
			Settings.Default.IncludeDifferencesOnly = includeDifferencesOnlyCheckBox.Checked;
			Settings.Default.AddonName = addonNameTextBox.Text;
			Settings.Default.AddonDescription = addonDescriptionTextBox.Text;
			Settings.Default.AddonNamespace = addonNamespaceTextBox.Text;
			Settings.Default.Save();
		}

		private void MainWindow_Shown(object sender, EventArgs e)
		{
			excelFilePathTextBox.Text = Settings.Default.ExcelFile;
			excelSheetNameTextBox.Text = Settings.Default.ExcelSheetName;
			includeDifferencesOnlyCheckBox.Checked = Settings.Default.IncludeDifferencesOnly;
			addonNameTextBox.Text = Settings.Default.AddonName;
			addonDescriptionTextBox.Text = Settings.Default.AddonDescription;
			addonNamespaceTextBox.Text = Settings.Default.AddonNamespace;
		}
	}
}