﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Windows.Forms;
using PowerGenerator.Properties;

namespace PowerGenerator
{
	/// <remarks>
	/// Toaster icon provided by Greg Barnes
	/// http://biggitybarnes.com/icons.html
	/// </remarks>
	internal static class Program
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		private static void Main()
		{
			var needsSave = false;
			if (Settings.Default.NeedsUpgrade)
			{
				Settings.Default.Upgrade();
				Settings.Default.NeedsUpgrade = false;
				needsSave = true;
			}

			// ReSharper disable once EmptyGeneralCatchClause
			try
			{
				const string defaultFileName = "POWER.xlsx";

				var poss = new[]
				{
					Settings.Default.ExcelFile,
					Path.Combine(Environment.CurrentDirectory, defaultFileName),
					Path.Combine(Assembly.GetExecutingAssembly().Location, defaultFileName),
				};

				var path = poss
					.Where(s => !string.IsNullOrWhiteSpace(s))
					.FirstOrDefault(File.Exists) ?? string.Empty;

				if (!string.Equals(path, Settings.Default.ExcelFile))
				{
					Settings.Default.ExcelFile = path;
					needsSave = true;
				}
			}
			catch (Exception)
			{
			}

			// ReSharper disable once EmptyGeneralCatchClause
			try
			{
				if (string.IsNullOrWhiteSpace(Settings.Default.OutputPath))
				{
					var prop = Settings.Default.Properties["AddonNamespace"];
					var addonDirName = prop == null ? "MyPowerMod" : (string) prop.DefaultValue;

					Settings.Default.OutputPath = Path.Combine(
						Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
						"Colossal Order", "Cities_Skylines", "Addons", "Mods", addonDirName, "Source");
					needsSave = true;
				}
			}
			catch (Exception)
			{
			}

			if (needsSave)
				Settings.Default.Save();

			Application.EnableVisualStyles();
			Application.SetCompatibleTextRenderingDefault(false);
			Application.Run(new MainWindow());
		}
	}
}